Editor Test: FontChoice Plugin

Content before the editor.

Editor with default drop down lists:

# Font Choice Plugin details

1. The Fontchoice plugin provides three dropdown menus for manipulating font information, such as font name, font size, and the format of the block containing the text (such as P, PRE, H1, and so on)
2. It auto-updates itself based on the caret and selection position in the document.

## Things to test:

1. Verify clicking in a P tag shows Paragraph in the dropdown.
2. Verify clicking in a a font-sized tag that the size dropdown indicates the current size (via a name).
3. Verify clicking in a a font-nameed tag that the name dropdown indicates the current font name.
4. Verify that you can set/manipulate all the above via the menu.

This is a pararaph.

    			This is preformatted text.

# This is a heading.

## This is a sub-heading.

### This is a sub-sub-heading.

This is some text in a 'p' for styling.

This is some more text in a 'p' for styling.

This is some small text.
This is some mediumish text.
This is some xx-large text.
This is some text in 'Comic Sans MS'.

# Selection format removal test

### Some H3 formatted content.

    				Some PRE formatted content.

Some P formatted content.

Content after the editor.
Content before the editor.

Editor w/ plain text dropdown values:

# Font Choice Plugin details

1. This instance of the FontChoice plugin just turns off formatted content in the dropdowns. Everything should be the same font and size.

## Things to test:

1. Verify that each of the dropdowns have values that are all the same size and font.

Content after the editor.

Editor w/ generic (web font names) font selector, traditional font name selector, font size selector, and format block selector:

hello world
Content after the editor.
Content before the editor.

Editor w/ custom font drop down list:

This editor should let you set the fonts to Verdana, Myriad, and Garamond.
Content after the editor.